==> rpm2html_1.8.1.orig.tar.gz: rpm2html-1.8.1/msg.pl <==
; 
; rpm2html language file
;
; Polish version by: Andrzej Baginski <andrzej.baginski@idk.com.pl>
; created: Sep 25 1998
; last modified: Sep 25 1998
;
;
; rpm2html language file
;
.html

Wygenerowany przez

index.html

Groups.html

ByDate.html

ByName.html

Vendors.html

Distribs.html

Witam w archiwum pakietw RPM na serwerze
    
<p>
<strong>rpm2html</strong> automatycznie generuje strony webowe opisujce 
pakiety <a href="http://www.rpm.org/">RPM</a>.</p>
<p>
<img src="new.gif" alt="New"><a href="http://rpmfind.net/linux/rpm2html/rpmfind.htm
l">
Uytkownicy programu Rpmfind</a> (pozwala zautomatyzowa przeszukiwanie
pakietw z bazy RPMw), 
musz zaktualizowa swoje wersje do wersji 0.98 lub nowszej poniewa
wsteczna kompatybilno wkrtce zostanie 
zaniechana. <a href="http://rpmfind.net/linux/rpm2html/download.html">Aktualizacja
...</a></p>
<p>
Celem programu rpm2html jest rwnie identyfikacja rnic 
pomidzy rnymi pakietami oraz odnajdywanie pakietw 
wymaganych przy instalacji danego pakietu. Kady pakiet 
jest analizowany by wycign z niego zasoby ktre zawiera. 
Te zalenoci s wyraane w hiper-poczeniach zawartych 
na generowanych stronach. Znalezienie zalenoci zasobw 
pakietu ktrego potrzebujesz jest kwestj kilku klikni 
myszk!</p>
<p>
Ostateczny efekt jest gwarantowany przez indeksowanie zbioru stron
pozwalajc w ten sposb uytkownikowi na instynktowne 
wyszukiwanie pakietu(w) speniajcych dane kryteria 
(przy zaoeniu, e opiekun pakietu poprawnie opisa 
pakiet).</p>
<p>
Naucz si <a href="http://rpmfind.net/linux/rpm2html/mirror.html">
jak zbudowa wasny mirror</a>. <B><FONT COLOR="#FF0000">
<FONT SIZE="+2"> Prosz nie prbowa mirrorowa kopii tego narzdzia webowego
</FONT></FONT></B></p>

Archiwum zawiera %d RPMw zajmujcych %d MBajtw danych

Na tym serwerze jest zainstalowanych %d RPMw, zajmujcych %d MBajtw danych

Lista

RPMw wg kategorii

RPMw wg daty utworzenia

RPMw wg nazwy

RPMw wg opiekuna pakietu
    
RPMw wg dystrybucji

RPMw wg daty instalacji

Archiwum rde

Lokalny mirror
    
Mirrory
    
Generowanie trwao

sekund.

Witam w opisie RPMu

Katalogi

Nazwa

Dystrybucja

Wersja

Dostawca

Rewizja

Data budowania pakietu

Data instalacji

Grupa

Serwer na ktrym zbudowano pakiet

Rozmiar

rdowy RPM

Pakujcy

Url

Opis

Zalenoci

Wymaga

Prawa autorskie

Pliki

Brak listy plikw w pakiecie !

Brak opisu !

Zasb RPM

Dostarczono przez

RPMy wg grupy

RPM(y) z grupy

RPMy wg dystrybucji

RPM(y) z dystrybucji

RPMy wg dostawcy

RPM(y) dostarczon(y/e) przez

RPMy wg daty utworzenia

RPMy wg daty instalacji

RPMy nie starsze ni trzy dni

RPMy nie starsze ni jeden tydzie

RPMy nie starsze ni dwa tygodnie

RPMy nie starsze ni jeden miesic

RPMy starsze ni 1 miesic

RPMy zainstalowane wczesniej ni trzy dni temu

RPMy zainstalowane wczesniej ni jeden tydzie temu

RPMy zainstalowane wczesniej ni dwa tygodnie temu

RPMy zainstalowane wczesniej ni jeden miesic temu

RPMy zainstalowane wczesniej ni 1 miesic temu

RPMy wg nazwy

Brak Opisu !

Nieznany

Nic

nieznany/grupa

nieznany.host

Indeks

pakiet(y/w) na liter

Uwaga: ten pakiet nie eksportuje odpowiednich list zasobw

Sprbuj wybra inny

Wicej

Historia zmian

Podkatalogi

Tree.html

Przegldaj drzewko dystrybucji

==> rpm2html_1.11.2.orig.tar.gz: rpm2html-1.11.2/msg.pl <==
; 
; rpm2html language file
;
; Polish version by: Andrzej Baginski <andrzej.baginski@idk.com.pl>
; created: Sep 25 1998
; last modified: Sep 25 1998
;
;
; rpm2html language file
;
.html

Wygenerowany przez

index.html

Groups.html

ByDate.html

ByName.html

Vendors.html

Distribs.html

Witam w archiwum pakietw RPM na serwerze
    
<p>
<strong>rpm2html</strong> automatycznie generuje strony webowe opisujce 
pakiety <a href="http://www.rpm.org/">RPM</a>.</p>
<p>
<img src="new.png" alt="New"><a href="http://rpmfind.net/linux/rpm2html/rpmfind.htm
l">
Uytkownicy programu Rpmfind</a> (pozwala zautomatyzowa przeszukiwanie
pakietw z bazy RPMw), 
musz zaktualizowa swoje wersje do wersji 0.98 lub nowszej poniewa
wsteczna kompatybilno wkrtce zostanie 
zaniechana. <a href="http://rpmfind.net/linux/rpm2html/download.html">Aktualizacja
...</a></p>
<p>
Celem programu rpm2html jest rwnie identyfikacja rnic 
pomidzy rnymi pakietami oraz odnajdywanie pakietw 
wymaganych przy instalacji danego pakietu. Kady pakiet 
jest analizowany by wycign z niego zasoby ktre zawiera. 
Te zalenoci s wyraane w hiper-poczeniach zawartych 
na generowanych stronach. Znalezienie zalenoci zasobw 
pakietu ktrego potrzebujesz jest kwestj kilku klikni 
myszk!</p>
<p>
Ostateczny efekt jest gwarantowany przez indeksowanie zbioru stron
pozwalajc w ten sposb uytkownikowi na instynktowne 
wyszukiwanie pakietu(w) speniajcych dane kryteria 
(przy zaoeniu, e opiekun pakietu poprawnie opisa 
pakiet).</p>
<p>
Naucz si <a href="http://rpmfind.net/linux/rpm2html/mirror.html">
jak zbudowa wasny mirror</a>. <B><FONT COLOR="#FF0000">
<FONT SIZE="+2"> Prosz nie prbowa mirrorowa kopii tego narzdzia webowego
</FONT></FONT></B></p>

Archiwum zawiera %d RPMw zajmujcych %d MBajtw danych

Na tym serwerze jest zainstalowanych %d RPMw, zajmujcych %d MBajtw danych

Lista

RPMw wg kategorii

RPMw wg daty utworzenia

RPMw wg nazwy

RPMw wg opiekuna pakietu
    
RPMw wg dystrybucji

RPMw wg daty instalacji

Archiwum rde

Lokalny mirror
    
Mirrory
    
Generowanie trwao

sekund.

Witam w opisie RPMu

Katalogi

Nazwa

Dystrybucja

Wersja

Dostawca

Rewizja

Data budowania pakietu

Data instalacji

Grupa

Serwer na ktrym zbudowano pakiet

Rozmiar

rdowy RPM

Pakujcy

Url

Opis

Zalenoci

Wymaga

Prawa autorskie

Pliki

Brak listy plikw w pakiecie !

Brak opisu !

Zasb RPM

Dostarczono przez

RPMy wg grupy

RPM(y) z grupy

RPMy wg dystrybucji

RPM(y) z dystrybucji

RPMy wg dostawcy

RPM(y) dostarczon(y/e) przez

RPMy wg daty utworzenia

RPMy wg daty instalacji

RPMy nie starsze ni trzy dni

RPMy nie starsze ni jeden tydzie

RPMy nie starsze ni dwa tygodnie

RPMy nie starsze ni jeden miesic

RPMy starsze ni 1 miesic

RPMy zainstalowane wczesniej ni trzy dni temu

RPMy zainstalowane wczesniej ni jeden tydzie temu

RPMy zainstalowane wczesniej ni dwa tygodnie temu

RPMy zainstalowane wczesniej ni jeden miesic temu

RPMy zainstalowane wczesniej ni 1 miesic temu

RPMy wg nazwy

Brak Opisu !

Nieznany

Nic

nieznany/grupa

nieznany.host

Indeks

pakiet(y/w) na liter

Uwaga: ten pakiet nie eksportuje odpowiednich list zasobw

Sprbuj wybra inny

Wicej

Historia zmian

Podkatalogi

Tree.html

Przegldaj drzewko dystrybucji
